@@ -15,8 +15,12 @@ def add_config(_C):
     # DataLoader
     # ---------------------------------------------------------------------------- #
     _C.DATALOADER = CN()
+    # batch size per GPU
     _C.DATALOADER.TRAIN_BATCH_SIZE = 16
     _C.DATALOADER.TEST_BATCH_SIZE = 16
 
     # refert to [torch Dataloader中的num_workers](https://zhuanlan.zhihu.com/p/69250939)
-    _C.DATALOADER.NUM_WORKERS = 4
+    _C.DATALOADER.NUM_WORKERS = 2
+
+    # overlapped prefetching cpu->gpu memory copy
+    _C.DATALOADER.PREFETCHER = False
