@@ -15,12 +15,11 @@ from .evaluator.general_evaluator import GeneralEvaluator
 
 class FashionMNIST(Dataset):
 
-    def __init__(self, root, train=True, transform=None, target_transform=None,
-                 download=False):
-        self.data_set = datasets.FashionMNIST(root, train=train, transform=transform, target_transform=target_transform,
-                                              download=download)
+    def __init__(self, root, train=True, transform=None, target_transform=None, top_k=(1, 5)):
+        self.data_set = datasets.FashionMNIST(root, train=train, transform=transform, target_transform=target_transform)
         self.classes = self.data_set.classes
-        self._update_evaluator()
+        self.root = root
+        self._update_evaluator(top_k)
 
     def __getitem__(self, index: int):
         return self.data_set.__getitem__(index)
@@ -28,5 +27,8 @@ class FashionMNIST(Dataset):
     def __len__(self) -> int:
         return self.data_set.__len__()
 
-    def _update_evaluator(self):
-        self.evaluator = GeneralEvaluator(self.classes, topk=(1, 5))
+    def _update_evaluator(self, top_k):
+        self.evaluator = GeneralEvaluator(self.classes, top_k=top_k)
+
+    def __repr__(self):
+        return self.__class__.__name__ + ' (' + self.root + ')'
